@@ -1,4 +1,4 @@
-// $Id: brush.cpp,v 1.3 2001/07/25 15:35:16 rich Exp $
+// $Id: brush.cpp,v 1.4 2001/10/10 17:57:45 mueller Exp $
 
 #include <stdio.h>
 #include <qcursor.h>
@@ -8,7 +8,7 @@
 #include <qclipboard.h>
 
 #include <klocale.h>
-#include <kapp.h>
+#include <kapplication.h>
 #include <kdebug.h>
 #include <kmessagebox.h>
 #include <kiconloader.h>
